@@ -377,7 +377,7 @@ class LoadMaster(HttpClient):
             for vs in services:
                 # add subvs to parent vs
                 if vs['MasterVSID'] == this_vs_index:
-                    subvs = VirtualService(self.access_info, vs['Index'])
+                    subvs = VirtualService(self.access_info, vs['Index'], is_sub_vs=True)
                     subvs.populate_default_attributes(vs)
                     subvs_api_entries = service.get("SubVS", [])
                     subvs_api_entries = cast_to_list(subvs_api_entries)
@@ -738,6 +738,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             "weight": self.subvs_data['Weight'],
             "limit": self.subvs_data['Limit'],
             "critical": self.subvs_data['Critical'],
+            "enable": self.subvs_data['Enable'],
         }
 
     @property
@@ -804,6 +805,8 @@ class VirtualService(HttpClient, KempBaseObjectModel):
                 if self._is_sub_vs:
                     # Update the underlying "Rs" part of the subvs as well
                     self._get("/modrs", self._subvs_to_dict())
+                    # Remove enable from the modvs request
+                    self.enable = None
                 response = self._get("/modvs", self.to_api_dict())
         except KempTechApiException:
             raise
@@ -841,6 +844,51 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.idletime = service.get('Idletime', None)
         self.mastervsid = service.get('MasterVSID', None)
 
+        self.alertthreshold = service.get('AlertThreshold', None)
+        self.querytag = service.get('QueryTag', None)
+        self.serverinit = service.get('ServerInit', None)
+        self.addvia = service.get('AddVia', None)
+        self.subnetoriginating = service.get('SubnetOriginating', None)
+        self.localbindaddrs = service.get('LocalBindAddrs', None)
+        self.defaultgw = service.get('DefaultGW', None)
+        #self.followvsid = falsey_to_none(int(service.get('FollowVSID', 0)))
+        self.standbyaddr = service.get('StandbyAddr', None)
+        self.standbyport = service.get('StandbyPort', None)
+        self.errorcode = service.get('ErrorCode', None)
+        self.errorurl = service.get('ErrorUrl', None)
+        self.errorpage = service.get('ErrorPage', None)
+
+        self.intercept = service.get('Intercept', None)
+        self.multiconnect = service.get('MultiConnect', None)
+        self.verify = service.get('Verify', None)
+        self.espenabled = service.get('EspEnabled', None)
+        self.compress = service.get('Compress', None)
+        self.cache = service.get('Cache', None)
+        self.cachepercent = service.get('CachePercent', None)
+
+        # SSL Acceleration
+        sslrewrite = {
+            "0": None,
+            "1": "http",
+            "2": "https",
+        }
+        self.sslacceleration = service.get('SSLAcceleration', None)
+        if self.sslacceleration:
+            self.tlstype = service.get('TlsType', None)
+            self.cipherset = service.get('CipherSet', None)
+            self.ciphers = service.get('Ciphers', None)
+        self.sslreencrypt = service.get('SSLReencrypt', None)
+        self.sslreverse = service.get('SSLReverse', None)
+        try:
+            self.sslrewrite = sslrewrite[service.get('SSLRewrite', "0")]
+        except KeyError:
+            self.sslrewrite = None
+        self.starttlsmode = service.get('StartTLSMode', None)
+        self.clientcert = service.get('ClientCert', None)
+        self.ocspverify = service.get('OCSPVerify', None)
+        # self.certfile = service.get('CertFile', None)
+        self.reversesnihostname = service.get('ReverseSNIHostname', None)
+
         # Real servers section
         self.checktype = service.get('CheckType', None)
         self.checkhost = service.get('CheckHost', None)
